@@ -109,31 +109,37 @@ protected:
     void closeEvent(QCloseEvent *) override;
     void showEvent(QShowEvent *event) override;
 
+private Q_SLOTS:
+    void slotDBusNotificationsPropertiesChanged(
+            const QString& interface,
+            const QVariantMap& changedProperties,
+            const QStringList& invalidatedProperties);
+
 private:
     void update();
     void updateButtons();
     typedef QList<ReminderTreeItem *> ReminderList;
 
-    static QDateTime triggerDateForIncidence(const KCalendarCore::Incidence::Ptr &inc, const QDateTime &reminderAt, QString &displayStr);
+    static Q_REQUIRED_RESULT QDateTime triggerDateForIncidence(const KCalendarCore::Incidence::Ptr &inc, const QDateTime &reminderAt, QString &displayStr);
 
     // Removes each Incidence-X group that has one of the specified uids
     void removeFromConfig(const QList<Akonadi::Item::Id> &);
 
     // Opens through dbus, @deprecated
-    bool openIncidenceEditorThroughKOrganizer(const KCalendarCore::Incidence::Ptr &incidence);
+    Q_REQUIRED_RESULT bool openIncidenceEditorThroughKOrganizer(const KCalendarCore::Incidence::Ptr &incidence);
 
     // opens directly
-    bool openIncidenceEditorNG(const Akonadi::Item &incidence);
+    Q_REQUIRED_RESULT bool openIncidenceEditorNG(const Akonadi::Item &incidence);
 
-    bool startKOrganizer();
+    Q_REQUIRED_RESULT bool startKOrganizer();
     ReminderTreeItem *searchByItem(const Akonadi::Item &incidence);
     void setTimer();
     void dismiss(const ReminderList &selections);
-    int activeCount();
-    ReminderList selectedItems() const;
+    Q_REQUIRED_RESULT int activeCount();
+    Q_REQUIRED_RESULT ReminderList selectedItems() const;
     void toggleDetails(QTreeWidgetItem *item);
     void showDetails(QTreeWidgetItem *item);
-    static bool grabFocus();
+    static Q_REQUIRED_RESULT bool grabFocus();
 
     Akonadi::ETMCalendar::Ptr mCalendar;
     QTreeWidget *mIncidenceTree = nullptr;
