@@ -926,13 +926,38 @@ void CalendarView::edit_options()
     mDialogManager->showOptionsDialog();
 }
 
+static QTime nextQuarterHour(const QTime &time)
+{
+    if (time.second() % 900) {
+        return time.addSecs(900 - (time.minute() * 60 + time.second()) % 900);
+    }
+    return time; //roundup not needed
+}
+
 void CalendarView::dateTimesForNewEvent(QDateTime &startDt, QDateTime &endDt, bool &allDay)
 {
     mViewManager->currentView()->eventDurationHint(startDt, endDt, allDay);
 
     if (!startDt.isValid() || !endDt.isValid()) {
         startDt.setDate(activeDate(true));
-        startDt.setTime(CalendarSupport::KCalPrefs::instance()->mStartTime.time());
+
+        QTime prefTime;
+        if (CalendarSupport::KCalPrefs::instance()->startTime().isValid()) {
+            prefTime = CalendarSupport::KCalPrefs::instance()->startTime().time();
+        }
+
+        const QDateTime currentDateTime = QDateTime::currentDateTime();
+        if (startDt.date() == currentDateTime.date()) {
+            // If today and the current time is already past the default time
+            // use the next quarter hour after the current time.
+            // but don't spill over into tomorrow.
+            const QTime currentTime = currentDateTime.time();
+            if (!prefTime.isValid() ||
+                (currentTime > prefTime && currentTime < QTime(23, 45))) {
+                prefTime = nextQuarterHour(currentTime);
+            }
+        }
+        startDt.setTime(prefTime);
 
         int addSecs
             = (CalendarSupport::KCalPrefs::instance()->mDefaultDuration.time().hour() * 3600)
