@@ -30,13 +30,11 @@
 #include <QDialog>
 class QPushButton;
 
-namespace CalendarSupport
-{
+namespace CalendarSupport {
 class IncidenceViewer;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Item;
 class ETMCalendar;
 }
@@ -49,7 +47,7 @@ class KORGANIZERPRIVATE_EXPORT KOEventViewerDialog : public QDialog
     Q_OBJECT
 public:
     explicit KOEventViewerDialog(Akonadi::ETMCalendar *calendar, QWidget *parent = nullptr);
-    virtual ~KOEventViewerDialog();
+    ~KOEventViewerDialog() override;
 
     void setIncidence(const Akonadi::Item &incidence, const QDate &date);
 
