@@ -29,7 +29,6 @@
 #include <KontactInterface/Core>
 
 #include <KActionCollection>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include "korganizerplugin_debug.h"
 #include <QAction>
@@ -43,8 +42,6 @@ JournalPlugin::JournalPlugin(KontactInterface::Core *core, const QVariantList &)
 {
     setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
 
-    KIconLoader::global()->addAppDir(QStringLiteral("korganizer"));
-
     QAction *action
         = new QAction(QIcon::fromTheme(QStringLiteral("journal-new")),
                       i18nc("@action:inmenu", "New Journal..."), this);
