@@ -42,7 +42,6 @@
 #include <KActionCollection>
 #include "korganizerplugin_debug.h"
 #include <QIcon>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QTemporaryFile>
@@ -57,7 +56,6 @@ KOrganizerPlugin::KOrganizerPlugin(KontactInterface::Core *core, const QVariantL
     , mIface(nullptr)
 {
     setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
-    KIconLoader::global()->addAppDir(QStringLiteral("korganizer"));
 
     QAction *action
         = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")),
@@ -215,7 +213,7 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
             QTemporaryFile tf;
             tf.setAutoRemove(true);
             tf.open();
-            QString uri = QStringLiteral("kmail:") + QString::number(mail.serialNumber());
+            QString uri = QLatin1String("kmail:") + QString::number(mail.serialNumber());
             tf.write(event->mimeData()->data(QStringLiteral("message/rfc822")));
             interface()->openEventEditor(
                 i18nc("@item", "Mail: %1", mail.subject()), txt,
