@@ -42,7 +42,6 @@
 #include <QMenu>
 #include <KLocalizedString>
 #include <KUrlLabel>
-#include <KIconLoader>
 #include <KConfigGroup>
 #include <KConfig>
 #include <QDesktopServices>
@@ -52,6 +51,7 @@
 #include <QEvent>
 #include <QLabel>
 #include <QGridLayout>
+#include <QStyle>
 
 using namespace KHolidays;
 
@@ -282,8 +282,8 @@ void SDSummaryWidget::createLabels()
          dt <= QDate::currentDate().addDays(mDaysAhead - 1);
          dt = dt.addDays(1)) {
         const KCalendarCore::Event::List events = mCalendar->events(dt, mCalendar->timeZone(),
-                                                               KCalendarCore::EventSortStartDate,
-                                                               KCalendarCore::SortDirectionAscending);
+                                                                    KCalendarCore::EventSortStartDate,
+                                                                    KCalendarCore::SortDirectionAscending);
         for (const KCalendarCore::Event::Ptr &ev : events) {
             // Optionally, show only my Events
             /* if ( mShowMineOnly &&
@@ -329,7 +329,7 @@ void SDSummaryWidget::createLabels()
                     }
 
                     // Append Anniversary Event?
-                    if (mShowAnniversariesFromCal && (itUpper == QStringLiteral("ANNIVERSARY"))) {
+                    if (mShowAnniversariesFromCal && (itUpper == QLatin1String("ANNIVERSARY"))) {
                         SDEntry entry;
                         entry.type = IncidenceTypeEvent;
                         entry.category = CategoryAnniversary;
@@ -463,7 +463,7 @@ void SDSummaryWidget::createLabels()
             }
             label = new QLabel(this);
             if (icon_img.isNull()) {
-                label->setPixmap(KIconLoader::global()->loadIcon(icon_name, KIconLoader::Small));
+                label->setPixmap(QIcon::fromTheme(icon_name).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)));
             } else {
                 label->setPixmap(QPixmap::fromImage(icon_img));
             }
@@ -691,13 +691,9 @@ void SDSummaryWidget::popupMenu(const QString &url)
 {
     QMenu popup(this);
     const QAction *sendMailAction
-        = popup.addAction(KIconLoader::global()->loadIcon(QStringLiteral("mail-message-new"),
-                                                          KIconLoader::Small),
-                          i18n("Send &Mail"));
+        = popup.addAction(QIcon::fromTheme(QStringLiteral("mail-message-new")), i18n("Send &Mail"));
     const QAction *viewContactAction
-        = popup.addAction(KIconLoader::global()->loadIcon(QStringLiteral("view-pim-contacts"),
-                                                          KIconLoader::Small),
-                          i18n("View &Contact"));
+        = popup.addAction(QIcon::fromTheme(QStringLiteral("view-pim-contacts")), i18n("View &Contact"));
 
     const QAction *ret = popup.exec(QCursor::pos());
     if (ret == sendMailAction) {
